General commands
| `help` | ```` | Prints help about the other commands. (try 'help help')
`exit` | ```` | Exits the shell.
`config` | ```` | Get/set configuration parameters.
`credits` | ```` | Shows the credits for compmake.
`reload` | ```` | Reloads a module.
Commands
| `clean` | ```` | Cleans the result of the selected computation (or everything is nothing specified).
`make` | ```` | Makes selected targets; or all targets if none specified.
`remake` | ```` | Remake the selected targets (equivalent to clean and make).
`more` | ```` | Makes more of the selected targets.
Parallel commands
| `parmake` | ```` | Parallel equivalent of "make".
`parremake` | ```` | Parallel equivalent of "remake".
`parmore` | ```` | Parallel equivalent of "more".
Cluster commands
| These assume that you have a cluster configuration file as explained in the documentation.
`clustmake` | ```` | Cluster equivalent of "make".
`clustmore` | ```` | Cluster equivalent of "more".
Visualization and diagnostics
| `graph` | ```` | Creates a graph of the given targets and dependencies
`list` | ```` | Lists the status of the selected targets (or all targets if not specified).
Import / export
| Ways to get data out of compmake.
`dump` | ```` | Dumps the content of jobs as pickle files.
Advanced commands
| Advanced commands not for general use
`make_single` | ```` | Makes a single job -- not for users, but for slave mode.
`commands_html` | ```` | Dumps the commands description in html on the specified file
`config_html` | ```` | Dumps the config description in html on the specified file.